<?php
/*
Plugin Name: 404 to URL
Plugin URI: http://www.fischercreativemedia.com/custom-plugins/
Description: Redirect all 404s to selected URL. Defaults to Home page if settings are left empty.
Version: 1.3
Author: Don Fischer
Author URI: http://www.fischercreativemedia.com/
Author Email: dfischer@fischercreativemedia.com
Text Domain: redirect-404-to-url
Domain Path: /lang
License: GPL2

  Copyright 2016 (dfischer@fischercreativemedia.com)

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2, as 
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

//Because this is not on the Repository, we need a way to update it if changed.
require_once( plugin_dir_path( __FILE__ ).'/updates/plugin-update-checker.php' );
new FCMPluginUpdateChecker_1_6 ( 'http://graphiccaffeine.com/wp-admin/admin-ajax.php', __FILE__ );

class fourOfourRedirectsToURL {
	function __construct() {
		add_action( 'admin_init', array( $this, 'custom_theme_add_option' ) );
		add_action( 'template_redirect', array( $this, 'personal_redirect_override' ), 11 );
		add_filter( 'redirect_canonical', array( $this, 'personal_redirect_override' ), 11 );
		add_action( 'plugins_loaded', array( $this, 'plugin_load_textdomain' ) );	// loads the plugin textdomain
	} 
	
	/**
	 * Load plugin textdomain.
	 *
	 * @since 1.0
	 */
	function plugin_load_textdomain() {
		load_plugin_textdomain( 'redirect-404-to-url', false, dirname( plugin_basename( __FILE__ ) ) . '/lang' ); 
	}

	/**
	 * Overrides the Redirect.
	 *
	 * @param $url string - URL 
	 * @return string - returns URL to use for Redirect
	 * @since 1.0
	 */
	function personal_redirect_override( $url = '') {
		if (!(defined('DOING_AJAX') && DOING_AJAX) && !is_admin()){
			if( is_404() ){
				$newURL = get_option( 'redirect_404url_url', get_bloginfo('home').'/' );
				$redTyp = get_option( 'redirect_404url_type', get_option( 'redirect_404url_type', '301' ) );
				wp_redirect( $newURL, $redTyp );
				exit;
			}
		}
		return $url;
	}
	
	/**
	 * Add plugin options to the Settings/Reading Page.
	 *
	 * @since 1.0
	 */
	function custom_theme_add_option(){
		add_settings_section( 'redirect_404url_settings_section', __( '404 Redirect to URL', 'redirect-404-to-url' ), array($this,'redirect_404url_options_callback_function'), 'reading' );
		register_setting( 'reading', 'redirect_404url_url' );
		register_setting( 'reading', 'redirect_404url_type' );
		add_settings_field( 'redirect_404url_url', __( '404 Redirect URL', 'redirect-404-to-url' ) , array($this, 'redirect_404url_url_callback_function' ), 'reading', 'redirect_404url_settings_section', array( 'label_for' => 'redirect_404url_url' ) );
		add_settings_field( 'redirect_404url_type', __( 'Redirect Type', 'redirect-404-to-url' ) , array($this, 'redirect_404url_type_callback_function' ), 'reading', 'redirect_404url_settings_section', array( 'label_for' => 'redirect_404url_type' ) );
	}
	
	/**
	 * Text for setting Group for custom_theme_add_option().
	 *
	 * @print string - Setting Group text
	 * @since 1.0
	 */
	function redirect_404url_options_callback_function(){
		echo '<p>' . __( 'Enter the URL where you want to redirect all 404s. The Homepage will be used if nothing it set. To return to normal 404 page, deativate plugin.', 'redirect-404-to-url' ) . '</p>';
		return;
	} 
	
	/**
	 * Option Callback for custom_theme_add_option() setting.
	 *
	 * @print string - Setting form field
	 * @since 1.0
	 */
	function redirect_404url_url_callback_function(){
		echo '<input name="redirect_404url_url" value="'.get_option( 'redirect_404url_url', '' ).'" class="regular-text" type="text"><p class="description">' . __( 'Enter the FULL URL of the site/page where you want all 404 errors to be redirected ( remember to include the http:// ).', 'redirect-404-to-url' ) . '</p>';
		return;
	}
	
	/**
	 * Option Callback for custom_theme_add_option() setting.
	 *
	 * @print string - Setting form field
	 * @since 1.0
	 */
	function redirect_404url_type_callback_function(){
		echo '
		<select name="redirect_404url_type">
			<option value="301"'.(get_option( 'redirect_404url_type', '301' ) == '301' ? ' selected="selected"' : '' ).'>301 ' . __( 'Permanent', 'redirect-404-to-url' ) . '</option>
			<option value="302"'.(get_option( 'redirect_404url_type', '301' ) == '302' ? ' selected="selected"' : '' ).'>302 ' . __( 'Temporary', 'redirect-404-to-url' ) . '</option>
		</select>
		<span class="description">&nbsp;' . __( 'Select the redirect type.', 'redirect-404-to-url' ) . '</span>';
		return;
	}
}

new fourOfourRedirectsToURL();